#!/usr/bin/ruby
#
#   check-mofo-provisioning
#
# DESCRIPTION:
#   Checks mofa logs and status
#
# OUTPUT:
#   plain text
#
# PLATFORMS:
#   Linux
#
# DEPENDENCIES:
#   gem: sensu-plugin
#
# USAGE:
#   check-container-logs.rb -H /tmp/docker.sock -n logspout -r 'problem sending' -r 'i/o timeout' -i 'Remark:' -i 'The configuration is'
#   => 1 container running = OK
#   => 4 container running = CRITICAL
#
# NOTES:
#   The API parameter required to use the limited lookback (-t) was introduced
#   the Docker server API version 1.19. This check may still work on older API
#   versions if you don't want to limit the timestamps of logs.
#
#

require 'sensu-plugin/check/cli'

class MofaProvisioningChecker < Sensu::Plugin::Check::CLI
  option :mofa_status_dir,
         description: 'Mofa Status dir - defaults to /var/lib/mofa',
         short: '-s /var/lib/mofa',
         long: '--mofa-status-dir /var/lib/mofa',
         default: '/var/lib/mofa'

  def process_mofa_status_dir(mofa_status_dir)
    data = { result: 'UNKNOWN' }
    if File.file?("#{mofa_status_dir}/last_status")
      status = File.read("#{mofa_status_dir}/last_status").chomp
      case
      when status =~ /SUCCESS/
        data['result'] = 'SUCCESS'
      when status =~ /FAIL/
        data['result'] = 'FAIL'
      end
    end
    data
  end

  def read_mofa_status_file(mofa_status_dir, status_file)
    content = ''
    puts status_file
    puts "#{mofa_status_dir}/#{status_file}"
    if File.file?("#{mofa_status_dir}/#{status_file}")
      content = File.read("#{mofa_status_dir}/#{status_file}").chomp
    end
    content
  end

  def run
    data = process_mofa_status_dir(config[:mofa_status_dir])
    case data['result']
    when 'SUCCESS'
      ok "Last mofa provisioning was successful (#{read_mofa_status_file(config[:mofa_status_dir], 'last_cookbook_name')}@#{read_mofa_status_file(config[:mofa_status_dir], 'last_cookbook_version')})"
    when 'FAIL'
      critical "Last mofa provisioning failed! (#{read_mofa_status_file(config[:mofa_status_dir], 'last_cookbook_name')}@#{read_mofa_status_file(config[:mofa_status_dir], 'last_cookbook_version')})"
    else
      unknown 'Cannot detect any mofa provisining (no cookbook info found).'
    end
  end
end
